# ARIC 
Accurate and robust inference of cell type proportions from bulk gene expression or DNA methylation data

# News
version 0.0.1, 2021.06.18
The first test version.

version 0.1.0, 2021.07.16
Add function to output all the markers.

